@@ -1,3 +1,3 @@
-$my.create_db $db
+$my.query("create database #{$db}")
 $created = true
 $my.select_db $db
